=============================================
API documentation for interacting with Galaxy
=============================================

GalaxyInstance
--------------

.. autoclass:: bioblend.galaxy.GalaxyInstance

    .. automethod:: bioblend.galaxy.GalaxyInstance.__init__

-----

.. _libraries-api:

Datasets
--------

.. automodule:: bioblend.galaxy.datasets

-----

Genomes
-------

.. automodule:: bioblend.galaxy.genomes

Histories
---------

.. automodule:: bioblend.galaxy.histories

-----

Libraries
---------

.. automodule:: bioblend.galaxy.libraries

-----

Quotas
--------

.. automodule:: bioblend.galaxy.quotas

-----

Tools
-----

.. automodule:: bioblend.galaxy.tools

-----

ToolShed
--------

.. automodule:: bioblend.galaxy.toolshed

-----

Users
-----

.. automodule:: bioblend.galaxy.users

-----

Visual
--------

.. automodule:: bioblend.galaxy.visual

-----

Workflows
---------

.. automodule:: bioblend.galaxy.workflows

-----
